@@ -157,13 +157,16 @@ pgroonga_crash_safer_reset_position_one(Datum databaseInfoDatum)
 		int result;
 
 		SetCurrentStatementStartTimestamp();
-		result =
-			SPI_execute("SELECT proname "
-						"  FROM pg_catalog.pg_proc "
-						"  WHERE "
-						"    proname = 'pgroonga_wal_set_applied_position'",
-						true,
-						0);
+		result = SPI_execute(
+			"SELECT nspname "
+			"  FROM pg_catalog.pg_namespace "
+			"  WHERE oid in ("
+			"    SELECT pronamespace "
+			"    FROM pg_catalog.pg_proc "
+			"    WHERE proname = 'pgroonga_wal_set_applied_position'"
+			")",
+			true,
+			0);
 		if (result != SPI_OK_SELECT)
 		{
 			ereport(FATAL,
@@ -177,9 +180,23 @@ pgroonga_crash_safer_reset_position_one(Datum databaseInfoDatum)
 
 		if (SPI_processed > 0)
 		{
+			bool isNULL;
+			Datum schemaNameDatum;
+			StringInfoData walSetAppliedPosition;
+
 			SetCurrentStatementStartTimestamp();
-			result = SPI_execute(
-				"SELECT pgroonga_wal_set_applied_position()", false, 0);
+			/**
+			 * The nspname column in pg_catalog.pg_namespace must not be NULL
+			 * because of NOT NULL constraint.
+			 */
+			schemaNameDatum = SPI_getbinval(
+				SPI_tuptable->vals[0], SPI_tuptable->tupdesc, 1, &isNULL);
+			initStringInfo(&walSetAppliedPosition);
+			appendStringInfo(&walSetAppliedPosition,
+							 "SELECT %s.pgroonga_wal_set_applied_position()",
+							 DatumGetCString(schemaNameDatum));
+			result = SPI_execute(walSetAppliedPosition.data, false, 0);
+			resetStringInfo(&walSetAppliedPosition);
 			if (result != SPI_OK_SELECT)
 			{
 				ereport(
@@ -549,7 +566,7 @@ pgroonga_crash_safer_flush_one(Datum databaseInfoDatum)
 		{
 			conditions =
 				WaitLatch(MyLatch,
-						  WL_LATCH_SET | WL_TIMEOUT | PGRN_WL_EXIT_ON_PM_DEATH,
+						  WL_LATCH_SET | WL_TIMEOUT | WL_EXIT_ON_PM_DEATH,
 						  timeout,
 						  PG_WAIT_EXTENSION);
 		}
@@ -607,11 +624,10 @@ pgroonga_crash_safer_flush_one(Datum databaseInfoDatum)
 				n_using_processes,
 				databaseOid,
 				tableSpaceOid);
-		conditions =
-			WaitLatch(MyLatch,
-					  WL_LATCH_SET | WL_TIMEOUT | PGRN_WL_EXIT_ON_PM_DEATH,
-					  PGroongaCrashSaferFlushNaptime * 1000,
-					  PG_WAIT_EXTENSION);
+		conditions = WaitLatch(MyLatch,
+							   WL_LATCH_SET | WL_TIMEOUT | WL_EXIT_ON_PM_DEATH,
+							   PGroongaCrashSaferFlushNaptime * 1000,
+							   PG_WAIT_EXTENSION);
 		if (conditions & WL_LATCH_SET)
 		{
 			ResetLatch(MyLatch);
@@ -773,10 +789,8 @@ pgroonga_crash_safer_main(Datum arg)
 	{
 		int conditions;
 
-		conditions = WaitLatch(MyLatch,
-							   WL_LATCH_SET | PGRN_WL_EXIT_ON_PM_DEATH,
-							   0,
-							   PG_WAIT_EXTENSION);
+		conditions = WaitLatch(
+			MyLatch, WL_LATCH_SET | WL_EXIT_ON_PM_DEATH, 0, PG_WAIT_EXTENSION);
 		if (conditions & WL_LATCH_SET)
 		{
 			ResetLatch(MyLatch);
